@@ -894,9 +894,7 @@ hildon_format_file_size_for_display(gint64 file_size)
 		return g_strdup_printf(_("ckdg_va_properties_size_10mb_1gb"),
                file_size / (1024.0f * 1024.0f));
 	else
-    /* Following calculation doesn't fit into 32 bits if the
-     * filesize is larger than 2^62 ;) */
 		return g_strdup_printf(_("ckdg_va_properties_size_1gb_or_greater"),
-               (int)(file_size / ((gint64)1024 * (gint64)1024 * (gint64)1024)));
+				       file_size / (1024.0 * 1024.0 * 1024.0));
 }
 
